@@ -12,9 +12,13 @@ class EKSStack(Stack):
         super().__init__(scope, construct_id, **kwargs)
 
         eks_role =  permission.iam.Role.from_role_arn(self, "eks_admin_role", role_arn=eks_role_arn)
+        eks_instance_profile = permission.createIAMInstanceProfile(self, "eks-instance-profile", eks_role)
         # eks_instance_profile = iam.CfnInstanceProfile(self, 'instanceprofile',
         #                                               roles=[eks_role.role_name],
         #                                               instance_profile_name='eks-cluster-role')
         
-        cluster = container.createEKSCluster(self, eks_cluster_name, eks_role, vpc)
-        nodegroup = container.addEKSClusterNodeGroup(self, cluster) 
+        # cluster = container.createEKS_EC2Cluster(self, eks_cluster_name, eks_role, vpc)
+        # nodegroup = container.addEKS_EC2ClusterNodeGroup(self, cluster) 
+
+        # FARGATE
+        fargate = container.createEKS_FargateCluster(self, eks_cluster_name, eks_role, vpc)
